#ifndef NT2_INCLUDE_FUNCTIONS_BITWISE_NOTOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITWISE_NOTOR_HPP_INCLUDED

#include <nt2/bitwise/include/functions/bitwise_notor.hpp>

#endif
